import React, { useState, useEffect } from "react";

export default function NavBar() {
  const [showMobileMenu, setShowMobileMenu] = useState(false);
  const [provider, setProvider] = useState(null);
  const [publicKey, setPublicKey] = useState(null);

  useEffect(() => {
    if (window.phantom?.solana) {
      setProvider(window.phantom.solana);
    }
  }, []);

  const handleConnectWallet = async () => {
    if (!provider) {
      alert("Phantom Wallet not detected!");
      return;
    }
    try {
      const resp = await provider.connect();
      setPublicKey(resp.publicKey.toString());
      console.log("Connected: ", resp.publicKey.toString());
    } catch (err) {
      console.error("Connection failed", err);
    }
  };

  useEffect(() => {
    if (!provider) return;
    provider.on("connect", (publicKey) => {
      setPublicKey(publicKey.toString());
    });
    provider.on("disconnect", () => {
      setPublicKey(null);
    });
  }, [provider]);

  return (
    <div className="fixed top-0 left-0 w-full h-[90px] z-50 bg-[#080808]">
      <div className="container mx-auto flex justify-between items-center py-4 px-6 md:px-20 lg:px-32">
        <a href="#home">
          <img
            src="/assets/logoaxali.png"
            className="w-[170px] mt-[10px]"
            alt="Logo"
          />
        </a>

        <ul className="hidden md:flex gap-7 text-white">
          <li>
            <a onClick={() => handleScrollToSection("Header")} className="cursor-pointer text-lg xl:text-[22.5px] font-dejavuSans">Home</a>
          </li>
          <li>
            <a href="https://trustify-ai-whitepaper.gitbook.io/trustify-docs" target="_blank" rel="noopener noreferrer" className="cursor-pointer text-lg xl:text-[22.5px] font-dejavuSans">Docs</a>
          </li>
          <li>
            <a onClick={() => handleScrollToSection("About")} className="cursor-pointer text-lg xl:text-[22.5px] font-dejavuSans">About Us</a>
          </li>
          <li>
            <a onClick={() => handleScrollToSection("team")} className="cursor-pointer text-lg xl:text-[22.5px] font-dejavuSans">Team</a>
          </li>
        </ul>

        <button onClick={handleConnectWallet} className="bg-blue-500 hover:bg-blue-700 text-white py-2 px-4 rounded hidden md:block">
          {publicKey ? "Connected" : "Connect Wallet"}
        </button>

        <img onClick={() => setShowMobileMenu(true)} src="/assets/menu.png" className="md:hidden w-7 cursor-pointer" alt="Menu Icon" />
      </div>

      <div className={`fixed inset-0 bg-black bg-opacity-80 z-50 transition-opacity duration-500 ${showMobileMenu ? "opacity-100 visible" : "opacity-0 invisible"}`}>
        <div className={`fixed top-0 left-0 h-full w-full bg-[#101010] text-white shadow-xl transform transition-transform duration-500 ${showMobileMenu ? "translate-x-0" : "-translate-x-full"}`}>
          <button onClick={() => setShowMobileMenu(false)} className="absolute top-4 right-4 text-3xl text-gray-300">✖</button>
          <ul className="flex flex-col items-center space-y-6 mt-20 text-2xl font-bold">
            <li onClick={() => { handleScrollToSection("home"); setShowMobileMenu(false); }}><a className="block py-2">Home</a></li>
            <li><a href="https://trustify-ai-whitepaper.gitbook.io/trustify-docs" target="_blank" rel="noopener noreferrer" className="block py-2">Docs</a></li>
            <li onClick={() => { handleScrollToSection("about"); setShowMobileMenu(false); }}><a className="block py-2">About Us</a></li>
            <li onClick={() => { handleScrollToSection("team"); setShowMobileMenu(false); }}><a className="block py-2">Team</a></li>
          </ul>

          <div className="flex justify-center mt-6">
            <button onClick={handleConnectWallet} className="bg-blue-500 hover:bg-blue-700 text-white py-3 px-6 rounded text-lg">
              {publicKey ? "Connected" : "Connect Wallet"}
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}
